sequencetools.all_are_integer_equivalent_numbers
================================================

.. autofunction:: abjad.tools.sequencetools.all_are_integer_equivalent_numbers.all_are_integer_equivalent_numbers
